package com.qs.mp.web.controller.api.admin;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qs.mp.channel.domain.Channel;
import com.qs.mp.channel.domain.vo.ChannelVO;
import com.qs.mp.channel.service.IChannelService;
import com.qs.mp.channel.service.IChannelUserRelService;
import com.qs.mp.common.core.domain.AjaxResult;
import com.qs.mp.common.core.page.TableDataInfo;
import com.qs.mp.system.domain.SysUser;
import com.qs.mp.system.service.ISysUserService;
import com.qs.mp.utils.SecurityUtils;
import com.qs.mp.web.controller.common.BaseApiController;
import io.swagger.annotations.Api;
import java.util.ArrayList;
import java.util.List;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @auther zhongcp
 * @create 2022-02-28 16:17:48
 * @describe 渠道管理前端控制器
 */
@Api("渠道管理API")
@RestController
@RequestMapping("/api/v1/mp/admin/channel/*")
@Component
public class ChannelTreeController extends BaseApiController {

	@Autowired
	private IChannelService channelService;
	
	@Autowired
	private IChannelUserRelService channelUserRelService;
	
	@Autowired
	private ISysUserService sysUserService;

	/**
	 * 获取我的下级渠道列表信息，支持翻页
	 *
	 * @return
	 */
	@PostMapping("/tree")
	public AjaxResult treeChannel(@RequestBody Channel channel) {
		Long channelId = SecurityUtils.getLoginUser().getChannelId();
		List<ChannelVO> list = new ArrayList<ChannelVO>();
		if(null != channelId) {
			QueryWrapper<Channel> queryWrapper = new QueryWrapper<>();
			queryWrapper.eq("t1.parent_id", channelId);
			queryWrapper.gt("t1.level", 0);
			queryWrapper.orderByAsc("t1.channel_id");
			list = channelService.selectChannelVoList(queryWrapper);
			if(null != list && list.size() > 0) {
				for(ChannelVO channelVO : list) {
					if(null != channelVO && StringUtils.isNotBlank(channelVO.getChannelNo())) {
//						int siteCnt = channelService.getChannelSiteCnt(channelVO.getChannelNo());
//						int userCnt = channelUserRelService.getChannelUserCnt(channelVO.getChannelNo());
//						channelVO.setSiteCnt(siteCnt);
//						channelVO.setUserCnt(userCnt);
						// 查询子渠道数量
						int childCnt = channelService.count(
								new LambdaQueryWrapper<Channel>().eq(Channel::getParentId, channelVO.getChannelId())
								.gt(Channel::getLevel, 0));
						channelVO.setChildCnt(childCnt);
					}
				}
			}
		}
		return AjaxResult.success(list);
	}
	
	/**
	 * 获取我的下级渠道列表信息，支持翻页
	 *
	 * @return
	 */
	@PostMapping("/list")
	public TableDataInfo listChannel(@RequestBody Channel channel) {
		Long channelId = SecurityUtils.getLoginUser().getChannelId();
		List<ChannelVO> list = new ArrayList<ChannelVO>();
		if(null != channelId) {
			channel.setParentId(channelId);
			startPage();
			QueryWrapper<Channel> queryWrapper = new QueryWrapper<>();
			queryWrapper.eq("t1.parent_id", channelId);
			queryWrapper.gt("t1.level", 0);
			queryWrapper.orderByAsc("t1.channel_id");
			list = channelService.selectChannelVoList(queryWrapper);
			if(null != list && list.size() > 0) {
				for(ChannelVO channelVO : list) {
					if(null != channelVO && StringUtils.isNotBlank(channelVO.getChannelNo())) {
						int siteCnt = channelService.getChannelSiteCnt(channelVO.getChannelNo());
						int userCnt = channelUserRelService.getChannelUserCnt(channelVO.getChannelNo());
						channelVO.setSiteCnt(siteCnt);
						channelVO.setUserCnt(userCnt);
						// 查询用户信息
						SysUser sysUser = sysUserService.selectUserById(channelId);
						channelVO.setSysUser(sysUser);

					}
				}
			}
		}
		return getDataTable(list);
	}
}
